@@ -30,7 +30,7 @@ import qubesadmin
 import qubesadmin.events
 import qubesadmin.exc
 import qubesadmin.vm
-from ..widgets.gtk_utils import show_error, show_dialog, load_theme
+from ..widgets.gtk_utils import show_error, show_dialog_with_icon, load_theme
 from ..widgets.gtk_widgets import ProgressBarDialog, ViewportHandler
 from ..widgets.utils import open_url_in_disposable
 from .page_handler import PageHandler
@@ -96,7 +96,8 @@ qubes.ClipboardPaste * @anyvm @anyvm ask\n""",
                 widget=self.copy_combo,
                 options={_('default (Ctrl+Shift+C)'): None,
                          _('Ctrl+Shift+C'): 'Ctrl-Shift-c',
-                         _('Ctrl+Win+C'): 'Ctrl-Mod4-c'},
+                         _('Ctrl+Win+C'): 'Ctrl-Mod4-c',
+                         _("Win+C"): 'Mod4-c'},
                 readable_name=_("Global Clipboard copy shortcut")
             ),
             FeatureHandler(
@@ -105,7 +106,8 @@ qubes.ClipboardPaste * @anyvm @anyvm ask\n""",
                 options= {_('default (Ctrl+Shift+V)'): None,
                           _('Ctrl+Shift+V'): 'Ctrl-Shift-V',
                           _('Ctrl+Win+V'): 'Ctrl-Mod4-v',
-                          _('Ctrl+Insert'): 'Ctrl-Ins'},
+                          _('Ctrl+Insert'): 'Ctrl-Ins',
+                          _('Win+V'): 'Mod4-v'},
                 readable_name=_("Global Clipboard paste shortcut")
             )
         ]
@@ -219,6 +221,7 @@ class GlobalConfig(Gtk.Application):
         else:
             height = self.main_window.get_allocated_height()
         self.main_window.resize(width, height)
+
         self.hold()
 
     @staticmethod
@@ -229,11 +232,6 @@ class GlobalConfig(Gtk.Application):
                            GObject.SignalFlags.RUN_LAST, GObject.TYPE_PYOBJECT,
                            (GObject.TYPE_PYOBJECT,))
 
-        GObject.signal_new('usbvm-changed',
-                           Gtk.Window,
-                           GObject.SignalFlags.RUN_LAST, GObject.TYPE_PYOBJECT,
-                           (GObject.TYPE_PYOBJECT,))
-
         # signal that informs other pages that a given page has been changed
         GObject.signal_new('page-changed',
                            Gtk.Window,
@@ -344,10 +342,13 @@ class GlobalConfig(Gtk.Application):
         self.progress_bar_dialog.update_progress(page_progress)
 
         self.main_notebook.connect("switch-page", self._page_switched)
-        self.main_window.connect('usbvm-changed', self._usbvm_changed)
 
         self._handle_urls()
 
+        self.progress_bar_dialog.update_progress(1)
+        self.progress_bar_dialog.hide()
+        self.progress_bar_dialog.destroy()
+
         self.viewport_handler = ViewportHandler(
             self.main_window,
             [self.builder.get_object('basics_scrolled_window'),
@@ -364,29 +365,11 @@ class GlobalConfig(Gtk.Application):
         self.progress_bar_dialog.hide()
         self.progress_bar_dialog.destroy()
 
-
-    def _usbvm_changed(self, *_args):
-        response = show_dialog(
-            parent=self.main_window, title=_("USB qube change"),
-            text=_("Changing USB qube requires restarting Global Settings to"
-                   "correctly initialize all defaults. "
-                   "Do you want to save changes and restart?"),
-            buttons={
-                _("_Save changes"): Gtk.ResponseType.YES,
-                _("_Discard changes"): Gtk.ResponseType.NO
-            }, icon_name="qubes-ask")
-        if response == Gtk.ResponseType.YES:
-            self._apply()
-            self._quit()
-            return
-        usb_handler = self.handlers['usb']
-        assert isinstance(usb_handler, DevicesHandler)
-        usb_handler.usbvm_handler.reset()
-
     def _handle_urls(self):
-        url_label_ids = ["url_info", "openinvm_info", "splitgpg_info",
-                         "usb_info", "basics_info", "thisdevice_security_info",
-                         "thisdevice_certified_yes_info"]
+        url_label_ids = ["basics_info", "u2fproxy_info", "splitgpg_info2",
+                         "copymove_info", "openinvm_info", "url_info",
+                         "thisdevice_certified_yes_info",
+                         "thisdevice_security_info"]
         for url_label_id in url_label_ids:
             label: Gtk.Label = self.builder.get_object(url_label_id)
             label.connect("activate-link", self._activate_link)
@@ -404,12 +387,18 @@ class GlobalConfig(Gtk.Application):
     def save_page(self, page: PageHandler) -> bool:
         """Save provided page and emit any necessary signals;
         return True if successful, False otherwise"""
+        # pylint: disable=protected-access
+        # need to invalidate cache before and after saving to avoid
+        # stale cache
+
+        self.qapp._invalidate_cache_all()
         try:
             page.save()
             for name, handler in self.handlers.items():
                 if handler == page:
                     self.main_window.emit('page-changed', name)
                     break
+            self.qapp._invalidate_cache_all()
             page.reset()
         except Exception as ex:
             show_error(self.main_window, _("Could not save changes"),
@@ -429,6 +418,7 @@ class GlobalConfig(Gtk.Application):
                     return self.save_page(page)
                 if response == Gtk.ResponseType.NO:
                     page.reset()
+                    return True
                 return False
         return True
 
@@ -458,7 +448,7 @@ class GlobalConfig(Gtk.Application):
         box.pack_start(label_2, False, False, 10)
         box.pack_start(label_3, False, False, 10)
 
-        response = show_dialog(
+        response = show_dialog_with_icon(
             parent=self.main_window, title=_("Unsaved changes"), text=box,
             buttons={
                 _("_Save changes"): Gtk.ResponseType.YES,
@@ -498,6 +488,7 @@ def main():
     Start the app
     """
     qapp = qubesadmin.Qubes()
+    qapp.cache_enabled = True
     policy_manager = PolicyManager()
     app = GlobalConfig(qapp, policy_manager)
     app.run(sys.argv)
