@@ -20,12 +20,12 @@
 """
 Updates page handler
 """
-import os
 import subprocess
 from html import escape
 from typing import Optional, List, Dict
 
 from qrexec.policy.parser import Rule
+from qrexec.client import call as qrexec_call
 
 from ..widgets.gtk_widgets import VMListModeler, NONE_CATEGORY
 from ..widgets.utils import get_boolean_feature, apply_feature_change
@@ -83,8 +83,8 @@ class RepoHandler:
             'qubes-dom0-security-testing': self.dom0_testing_sec_radio,
             'qubes-dom0-current-testing': self.dom0_testing_radio,
             },
-            {'qubes-templates-itl-testing': self.template_official_testing,
-            'qubes-templates-itl': self.template_official},
+            {'qubes-templates-itl': self.template_official,
+             'qubes-templates-itl-testing': self.template_official_testing},
             {'qubes-templates-community': self.template_community,
              'qubes-templates-community-testing':
                 self.template_community_testing,
@@ -114,7 +114,7 @@ class RepoHandler:
                 self.repos[repo_name] = {}
                 self.repos[repo_name]['prettyname'] = lst[1]
                 self.repos[repo_name]['enabled'] = lst[2] == 'enabled'
-        except RuntimeError as ex:
+        except (RuntimeError, IndexError) as ex:
             # disable all repo-related stuff
             self.dom0_stable_radio.set_sensitive(False)
             self.dom0_testing_sec_radio.set_sensitive(False)
@@ -142,19 +142,12 @@ class RepoHandler:
 
     @staticmethod
     def _run_qrexec_repo(service, arg=''):
-        # Set default locale to C in order to prevent error msg
-        # in subprocess call related to falling back to C locale
-        env = os.environ.copy()
-        env['LC_ALL'] = 'C'
-        # Fake up a "qrexec call" to dom0 because dom0 can't qrexec to itself
-        cmd = '/etc/qubes-rpc/' + service
-        # --non-interactive is a workaround for sudo bug
-        process = subprocess.run(['sudo', '--non-interactive', cmd, arg],
-                           stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-                           check=False, env=env)
-        if process.returncode != 0 or process.stderr:
-            raise RuntimeError('qrexec call failed')
-        return process.stdout.decode('utf-8')
+        try:
+            return qrexec_call('dom0', service, arg)
+        except subprocess.CalledProcessError as ex:
+            raise RuntimeError('qrexec call failed: ' + str(ex.stderr)) from ex
+        except Exception as ex:
+            raise RuntimeError('qrexec call failed: ' + str(ex)) from ex
 
     def _set_repository(self, repository, state):
         action = 'Enable' if state else 'Disable'
@@ -200,11 +193,11 @@ class RepoHandler:
             found = False
             for repo, widget in repo_dict.items():
                 try:
-                    if widget.get_active() or found:
+                    if widget.get_active():
                         found = True
-                        self._set_repository(repo, widget.get_active())
+                        self._set_repository(repo, True)
                     else:
-                        self._set_repository(repo, False)
+                        self._set_repository(repo, not found)
                 except RuntimeError as ex:
                     raise qubesadmin.exc.QubesException(
                         'Failed to set repository data: '
@@ -367,7 +360,7 @@ class UpdateProxy:
 
         self.has_whonix = self._check_for_whonix()
 
-        self.default_updatevm = self.qapp.domains['sys-net']
+        self.default_updatevm = self.qapp.domains.get('sys-net', None)
         self.default_whonix_updatevm = self.qapp.domains.get('sys-whonix', None)
 
         self.first_eligible_vm = None
@@ -384,9 +377,8 @@ class UpdateProxy:
         self.whonix_updatevm_box: Gtk.Box = \
             gtk_builder.get_object('updates_whonix_updatevm_box')
 
-        self.rules, self.current_token = \
-            self.policy_manager.get_rules_from_filename(
-                self.policy_file_name, "")
+        self.rules: List[Rule] = []
+        self.current_token: Optional[str] = None
 
         self.exception_list_handler = PolicyExceptionsHandler(
             gtk_builder=gtk_builder, prefix='updates_updatevm',
@@ -397,11 +389,13 @@ class UpdateProxy:
         self.updatevm_model = VMListModeler(
             combobox=self.def_updatevm_combo, qapp=self.qapp,
             filter_function=self._updatevm_filter,
-            current_value=None)
+            current_value=None, additional_options={
+                "None": _("(none)")})
         self.whonix_updatevm_model = VMListModeler(
             combobox=self.whonix_updatevm_combo, qapp=self.qapp,
             filter_function=self._whonixupdatevm_filter,
-            current_value=None)
+            current_value=None, additional_options={
+                "None": _("(none)")})
 
         self.load_rules()
 
@@ -435,12 +429,17 @@ class UpdateProxy:
             return False
         if getattr(vm, 'template', None):
             return False
-        return not vm.is_networked()
+        return bool(vm.features.check_with_template(
+            'service.updates-proxy-setup', vm.klass == 'TemplateVM'))
 
     def load_rules(self):
         """Load rules into widgets."""
+        self.rules, self.current_token = \
+            self.policy_manager.get_rules_from_filename(
+                self.policy_file_name, "")
         def_updatevm = self.default_updatevm
         def_whonix_updatevm = None
+
         if self.has_whonix:
             def_whonix_updatevm = self.default_whonix_updatevm
 
@@ -450,8 +449,9 @@ class UpdateProxy:
             elif rule.source == '@tag:whonix-updatevm':
                 def_whonix_updatevm = rule.action.target
 
-        self.updatevm_model.select_value(str(def_updatevm))
-        self.updatevm_model.update_initial()
+        if def_updatevm:
+            self.updatevm_model.select_value(str(def_updatevm))
+            self.updatevm_model.update_initial()
 
         if self.has_whonix:
             self.whonix_updatevm_model.select_value(str(def_whonix_updatevm))
@@ -539,12 +539,13 @@ class UpdateProxy:
                     f"target={self.whonix_updatevm_model.get_selected()}"))
             new_update_proxies.add(self.whonix_updatevm_model.get_selected())
 
-        raw_rules.append(
-            self.policy_manager.new_rule(service=self.service_name,
-                source="@type:TemplateVM", target="@default",
-                action="allow "
-                       f"target={self.updatevm_model.get_selected()}"))
-        new_update_proxies.add(self.updatevm_model.get_selected())
+        if self.updatevm_model.get_selected():
+            raw_rules.append(
+                self.policy_manager.new_rule(service=self.service_name,
+                    source="@type:TemplateVM", target="@default",
+                    action="allow "
+                           f"target={self.updatevm_model.get_selected()}"))
+            new_update_proxies.add(self.updatevm_model.get_selected())
 
         self.policy_manager.save_rules(self.policy_file_name,
                                        raw_rules, self.current_token)
