@@ -162,8 +162,13 @@ def add_expected_vm(qapp,
         qapp.expected_calls[(name, "admin.vm.tag.Get", tag, None)] = \
             b"0\x001"
 
+    qapp.expected_calls[(name, "admin.vm.device.pci.List", None, None)] = \
+        b"0\x00"
+
 def add_dom0_vm_property(qapp, prop_name, prop_value):
     """Add a vm property to dom0"""
+    if not prop_value:
+        prop_value = ""
     qapp.expected_calls[('dom0', 'admin.property.Get', prop_name, None)] = \
         b'0\x00' + f'default=True type=vm {prop_value}'.encode()
 
@@ -180,7 +185,8 @@ def add_dom0_feature(qapp, feature, feature_value):
             b'0\x00' + f'{feature_value}'.encode()
     else:
         qapp.expected_calls[('dom0', 'admin.vm.feature.Get', feature, None)] = \
-            b'0\x00' + f'{feature_value}'.encode()
+            b'2\x00QubesFeatureNotFoundError\x00\x00' \
+            + str(feature).encode() + b'\x00'
 
 def add_feature_with_template_to_all(qapp, feature_name,
                                      enable_vm_names: List[str]):
@@ -211,6 +217,10 @@ def add_feature_to_all(qapp, feature_name, enable_vm_names: List[str]):
 
 @pytest.fixture
 def test_qapp():
+    return test_qapp_impl()
+
+
+def test_qapp_impl():
     """Test QubesApp"""
     qapp = QubesTest()
     qapp._local_name = 'dom0'  # pylint: disable=protected-access
@@ -292,6 +302,8 @@ def test_qapp():
 
     add_feature_with_template_to_all(qapp, 'supported-service.qubes-u2f-proxy',
                                      ['test-vm', 'fedora-35', 'sys-usb'])
+    add_feature_with_template_to_all(qapp, 'service.updates-proxy-setup',
+                                     ['fedora-36', 'fedora-35'])
     add_feature_to_all(qapp, 'service.qubes-u2f-proxy',
                                      ['test-vm'])
 
@@ -316,8 +328,102 @@ def test_qapp_whonix(test_qapp):  # pylint: disable=redefined-outer-name
                     {"netvm": ("vm", False, '')},
                     {'service.qubes-update-check': None}, ['whonix-updatevm'])
     test_qapp.domains.clear_cache()
+    add_feature_with_template_to_all(
+        test_qapp, 'service.updates-proxy-setup',
+        ['fedora-36', 'fedora-35', 'whonix-gw-15', 'whonix-gw-14'])
     return test_qapp
 
+@pytest.fixture
+def test_qapp_simple(): # pylint: disable=redefined-outer-name
+    """A qapp with only one template, one sys-net and that's all"""
+    # pylint does not understand fixtures
+    qapp = QubesTest()
+    qapp._local_name = 'dom0'  # pylint: disable=protected-access
+
+    add_dom0_vm_property(qapp, 'clockvm', 'sys-net')
+    add_dom0_vm_property(qapp, 'updatevm', 'sys-net')
+    add_dom0_vm_property(qapp, 'default_netvm', 'sys-net')
+    add_dom0_vm_property(qapp, 'default_template', 'fedora-36')
+    add_dom0_vm_property(qapp, 'default_dispvm', 'fedora-36')
+
+    add_dom0_text_property(qapp, 'default_kernel', '1.1')
+    add_dom0_text_property(qapp, 'default_pool', 'file')
+
+    add_dom0_feature(qapp, 'gui-default-allow-fullscreen', '')
+    add_dom0_feature(qapp, 'gui-default-allow-utf8-titles', '')
+    add_dom0_feature(qapp, 'gui-default-trayicon-mode', '')
+
+    # setup labels
+    qapp.expected_calls[('dom0', 'admin.label.List', None, None)] = \
+        b'0\x00red\nblue\ngreen\n'
+
+    # setup pools:
+    qapp.expected_calls[('dom0', 'admin.pool.List', None, None)] = \
+        b'0\x00linux-kernel\nlvm\nfile\n'
+    qapp.expected_calls[('dom0', 'admin.pool.volume.List',
+                         'linux-kernel', None)] = \
+        b'0\x001.1\nmisc\n4.2\n'
+
+    add_expected_vm(qapp, 'dom0', 'AdminVM',
+                    {}, {'service.qubes-update-check': 1,
+                         'config.default.qubes-update-check': None,
+                         'config-usbvm-name': None,
+                         'gui-default-secure-copy-sequence': None,
+                         'gui-default-secure-paste-sequence': None
+                         }, [])
+    add_expected_vm(qapp, 'sys-net', 'AppVM',
+                    {'provides_network': ('bool', False, 'True')},
+                    {'service.qubes-update-check': None,
+                     'service.qubes-updates-proxy': 1}, [])
+
+    add_expected_vm(qapp, 'fedora-36', 'TemplateVM',
+                    {"netvm": ("vm", False, '')},
+                    {'service.qubes-update-check': None}, [])
+
+    return qapp
+
+
+@pytest.fixture
+def test_qapp_broken():  # pylint: disable=redefined-outer-name
+    """A qapp with no templates, no sys-net"""
+    # pylint does not understand fixtures
+    qapp = QubesTest()
+    qapp._local_name = 'dom0'  # pylint: disable=protected-access
+
+    add_dom0_vm_property(qapp, 'clockvm', None)
+    add_dom0_vm_property(qapp, 'updatevm', None)
+    add_dom0_vm_property(qapp, 'default_netvm', None)
+    add_dom0_vm_property(qapp, 'default_template', None)
+    add_dom0_vm_property(qapp, 'default_dispvm', None)
+
+    add_dom0_text_property(qapp, 'default_kernel', '1.1')
+    add_dom0_text_property(qapp, 'default_pool', 'file')
+
+    add_dom0_feature(qapp, 'gui-default-allow-fullscreen', '')
+    add_dom0_feature(qapp, 'gui-default-allow-utf8-titles', '')
+    add_dom0_feature(qapp, 'gui-default-trayicon-mode', '')
+
+    # setup labels
+    qapp.expected_calls[('dom0', 'admin.label.List', None, None)] = \
+        b'0\x00red\nblue\ngreen\n'
+
+    # setup pools:
+    qapp.expected_calls[('dom0', 'admin.pool.List', None, None)] = \
+        b'0\x00linux-kernel\nlvm\nfile\n'
+    qapp.expected_calls[('dom0', 'admin.pool.volume.List',
+                         'linux-kernel', None)] = \
+        b'0\x001.1\nmisc\n4.2\n'
+
+    add_expected_vm(qapp, 'dom0', 'AdminVM',
+                    {}, {'service.qubes-update-check': 1,
+                         'config.default.qubes-update-check': None,
+                         'config-usbvm-name': None,
+                         'gui-default-secure-copy-sequence': None,
+                         'gui-default-secure-paste-sequence': None
+                         }, [])
+    return qapp
+
+
 SIGNALS_REGISTERED = False
 
 @pytest.fixture
@@ -349,7 +455,6 @@ def real_builder():
     return builder
 
 
-
 NEW_QUBE_SIGNALS_REGISTERED = False
 
 
